import { ArraySerializerOptions, BoolSerializerOptions, BytesSerializerOptions, DataEnum, DataEnumSerializerOptions, DataEnumToSerializerTuple, EnumSerializerOptions, MapSerializerOptions, Nullable, NullableSerializerOptions, NumberSerializerOptions, Option, OptionSerializerOptions, PublicKey, PublicKeyInput, PublicKeySerializerOptions, ScalarEnum, Serializer, SerializerInterface, SetSerializerOptions, StringSerializerOptions, StructSerializerOptions, StructToSerializerTuple, TupleSerializerOptions, UnitSerializerOptions, WrapInSerializer } from '@metaplex-foundation/umi-core';
export declare class BeetSerializer implements SerializerInterface {
    protected readonly options: {
        /** @defaultValue `true` */
        tolerateEmptyBuffers?: boolean;
    };
    constructor(options?: {
        /** @defaultValue `true` */
        tolerateEmptyBuffers?: boolean;
    });
    tuple<T extends any[], U extends T = T>(items: WrapInSerializer<[...T], [...U]>, options?: TupleSerializerOptions): Serializer<T, U>;
    array<T, U extends T = T>(item: Serializer<T, U>, options?: ArraySerializerOptions): Serializer<T[], U[]>;
    map<TK, TV, UK extends TK = TK, UV extends TV = TV>(key: Serializer<TK, UK>, value: Serializer<TV, UV>, options?: MapSerializerOptions): Serializer<Map<TK, TV>, Map<UK, UV>>;
    set<T, U extends T = T>(item: Serializer<T, U>, options?: SetSerializerOptions): Serializer<Set<T>, Set<U>>;
    option<T, U extends T = T>(item: Serializer<T, U>, options?: OptionSerializerOptions): Serializer<Option<T>, Option<U>>;
    nullable<T, U extends T = T>(item: Serializer<T, U>, options?: NullableSerializerOptions): Serializer<Nullable<T>, Nullable<U>>;
    struct<T extends object, U extends T = T>(fields: StructToSerializerTuple<T, U>, options?: StructSerializerOptions): Serializer<T, U>;
    enum<T>(constructor: ScalarEnum<T> & {}, options?: EnumSerializerOptions): Serializer<T>;
    dataEnum<T extends DataEnum, U extends T = T>(variants: DataEnumToSerializerTuple<T, U>, options?: DataEnumSerializerOptions): Serializer<T, U>;
    string(options?: StringSerializerOptions): Serializer<string>;
    bool(options?: BoolSerializerOptions): Serializer<boolean>;
    unit(options?: UnitSerializerOptions): Serializer<void>;
    u8(options?: NumberSerializerOptions): Serializer<number>;
    u16(options?: NumberSerializerOptions): Serializer<number>;
    u32(options?: NumberSerializerOptions): Serializer<number>;
    u64(options?: NumberSerializerOptions): Serializer<number | bigint, bigint>;
    u128(options?: NumberSerializerOptions): Serializer<number | bigint, bigint>;
    i8(options?: NumberSerializerOptions): Serializer<number>;
    i16(options?: NumberSerializerOptions): Serializer<number>;
    i32(options?: NumberSerializerOptions): Serializer<number>;
    i64(options?: NumberSerializerOptions): Serializer<number | bigint, bigint>;
    i128(options?: NumberSerializerOptions): Serializer<number | bigint, bigint>;
    f32(): Serializer<number>;
    f64(): Serializer<number>;
    bytes(options?: BytesSerializerOptions): Serializer<Uint8Array>;
    publicKey(options?: PublicKeySerializerOptions): Serializer<PublicKeyInput, PublicKey>;
    protected handleEmptyBuffer<T>(serializer: string, defaultValue: T, offset: number): [T, number];
}
